pub trait VerboseDisplay: Display {
// Provided method
fn write_str(&self, w: &mut dyn Write) -> Result { ... }
}๐Deprecated since 3.1.0:
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Provided Methods
fn write_str(&self, w: &mut dyn Write) -> Result
๐Deprecated since 3.1.0:
This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.